pub struct Issue {
pub code: String,
pub message: String,
pub severity: Severity,
pub attribute_name: Option<String>,
}Expand description
Issue : An issue with a listings item.
Fields
code: StringAn issue code that identifies the type of issue.
message: StringA message that describes the issue.
severity: SeverityThe severity of the issue.
attribute_name: Option<String>Name of the attribute associated with the issue, if applicable.
Implementations